import json

from django.http import JsonResponse
from rest_framework.views import APIView

from datetime import datetime

from django.views.decorators.csrf import ensure_csrf_cookie

from api import serializers
from web.models import Article


@ensure_csrf_cookie
def echo_view(request, *args, **kwargs):
    answer = {
        'time': datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
        'method': request.method,
    }
    
    print(request.body)

    if request.method == 'POST':
        if request.body:
            answer['content'] = json.loads(request.body)
    
    return JsonResponse(answer)


class ArticlesView(APIView):
    def get(self, request, *args, **kwargs):
        qs = Article.objects.all()
        serializer = serializers.ArticleSerializer(qs, many=True)
        return JsonResponse(serializer.data, safe=False)

    def post(self, request, *args, **kwargs):
        data = json.loads(request.body)
        serializer = serializers.ArticleSerializer(data=data)

        if serializer.is_valid():
            serializer.save()
            return JsonResponse(serializer.data, safe=False)

        else:
            return JsonResponse(status=400, data={'errors': serializer.error_messages})


class ArticleUpdateView(APIView):
    def update(self, request, id_, partial: bool = True):
        serializer = serializers.ArticleSerializer

        if partial:
            serializer = serializers.ArticlePartialUpdateSerializer

        instance = Article.objects.get(id=id_)

        data = json.loads(request.body)
        serializer = serializer(data=data, instance=instance)

        if serializer.is_valid():
            serializer.save()
            return JsonResponse(serializer.data, safe=True)
        else:
            return JsonResponse(status=400, data={'errors': serializer.error_messages})

    def put(self, request, id_: int, *args, **kwargs):
        return self.update(request, id_, partial=False)

    def patch(self, request, id_, *args, **kwargs):
        return self.update(request, id_)
