from django import forms
from django.forms import widgets, ValidationError

from core.validators import at_least_5
from web.models import Article, Comment


class ArticleForm(forms.Form):
    title = forms.CharField(max_length=200, required=True, label='Title')
    author = forms.CharField(max_length=40, required=True, label='Author')
    status = forms.CharField(required=True, label='Status')
    text = forms.CharField(max_length=3000, required=True, label='Text', widget=widgets.Textarea)


class ArticleModelForm(forms.ModelForm):
    class Meta:
        model = Article
        fields = ('title', 'author', 'status', 'text', 'tags')
        widgets = {
            'title': forms.TextInput(attrs={'class': 'form-control mb-3'}),
            'author': forms.HiddenInput(attrs={'class': 'form-control mb-3'}),
            'status': forms.Select(attrs={'class': 'form-select mb-3'}),
            'text': forms.Textarea(attrs={'class': 'form-control mb-3'}),
            'tags': forms.CheckboxSelectMultiple(attrs={'class': 'mb-3'})
        }

    def clean(self):
        cleaned_data = super().clean()
        if cleaned_data.get('text') == cleaned_data.get('title'):
            raise ValidationError('Text of the article should not duplicate it\'s title')

        return cleaned_data


class CommentModelForm(forms.ModelForm):
    class Meta:
        model = Comment
        fields = ['text']
        widgets = {
            'text': forms.TextInput(attrs={'class': 'form-control mb-3'}),
        }


class SearchForm(forms.Form):
    search = forms.CharField(
        max_length=100,
        required=False,
        label='Найти',
        widget=forms.TextInput(attrs={
            'class': 'form-control my-3',
            'placeholder': 'enter search value'
        })
    )
