from django.urls import reverse
from django.views.generic import (
    CreateView,
    UpdateView,
    DeleteView
)
from django.contrib.auth.mixins import PermissionRequiredMixin
from web.forms import CommentModelForm
from web.models import Comment


class CommentCreateView(CreateView):
    model = Comment
    template_name = 'comment/create_update.html'
    form_class = CommentModelForm

    def form_valid(self, form):
        form.instance.author_id = self.request.session.get('author_id')
        form.instance.article_id = self.request.session.get('article_id')
        return super().form_valid(form)

    def get_success_url(self):
        return reverse('article_detail', kwargs={'id': self.object.article.id})


class CommentUpdateView(PermissionRequiredMixin, UpdateView):
    model = Comment
    template_name = 'comment/create_update.html'
    context_object_name = 'comment'
    pk_url_kwarg = 'id'
    form_class = CommentModelForm
    extra_context = {'button_text': 'Update', 'title': 'Update comment'}
    permission_required = 'web.change_comment'
    
    def get_initial(self):
        return self.object.__dict__

    def has_permission(self):
        return super().has_permission() or self.request.user == self.get_object().author

    def get_success_url(self):
        return reverse('article_detail', kwargs={'id': self.object.article.id})


class CommentDeleteView(DeleteView):
    model = Comment
    pk_url_kwarg = 'id'

    def get_success_url(self):
        return reverse('article_detail', kwargs={'id': self.object.article.id})
